@@ -73,4 +73,4 @@ class SimpleProcessor(BaseProcessor):
             task.retries = 0
             task.exception = None
             break
-        task.shutdown()
+        # task.shutdown()
