@@ -95,7 +95,7 @@ def add_task(self, tp):
     :return:
     """
     if self.data['command'] == 'stop':
-        tp.stop(name=self.data['foo'], workers_count=self.data['max_workers'], leave_last=False)
+        tp.stop(task_name=self.data['foo'], workers_count=self.data['max_workers'], leave_last=False)
         self.app.logger.info("%d workers was deleted from task %s" % (self.data['max_workers'], self.data['foo']))
     elif self.data['command'] == 'start':
         tp.add_task(foo=func_import(self.data['foo']), queue=TARANTOOL_QUEUE, args=[1, 'message from new worker'],
